﻿<?php

require 'textreplace.php';

define('FAMILY_PREFIX', 'tr_');
define('FAMILY_PREFIX_LEN', strlen(FAMILY_PREFIX));

/**
 * Classe du plugin plxTextReplace
 *
 * @package PLX
 * @version 1.0
 * @date	08/01/2012
 * @author	Humpf
 **/
class plxtextreplace extends plxPlugin {

	protected $tr;
	
	
	/**
	 * Constructeur de la classe
	 *
	 * @return	null
	 * @author	Humpf
	 **/
	public function __construct($default_lang) {

		# Appel du constructeur de la classe plxPlugin (obligatoire)
		parent::__construct($default_lang);

		# Droits pour accèder à la page config.php du plugin
		$this->setConfigProfil(PROFIL_ADMIN);

		# Ajouts des hooks
		$this->addHook('IndexEnd', 'IndexEnd');
		
		# Chargement des familles de tags
		$this->loadPatterns();
	}

	/**
	 * Charge les fichiers de descriptions des tags en fonction des paramètres du plugin.
	 * Utiliser le fichier 'tags-custom.xml' pour définir les patterns parso
	 * Par défaut, tous les patterns sont chargés.
	 *
	 * @return	null
	 * @author	Humpf
	 **/
	public function loadPatterns() {
		foreach($this->aParams as $key => $value) {
			if (strpos($key, FAMILY_PREFIX) === 0) {
				if ($value['value'] == 1) {
					$aFamiliesToLoad[] = substr($key, FAMILY_PREFIX_LEN);
				} elseif (!isset($aFamiliesToLoad)) {
					$aFamiliesToLoad = array();
				}
			}
		}
		# Si aucun paramètre, toutes les familles sont à charger
		if (!isset($aFamiliesToLoad)) {
			$aFamiliesToLoad = NULL;
		}
		$plugName = get_class($this);
		$this->tr = new TextReplace($aFamiliesToLoad);
		$this->tr->loadPatterns(PLX_PLUGINS.$plugName.'/tags-default.xml');
		$this->tr->loadPatterns(PLX_PLUGINS.$plugName.'/tags-custom.xml');
	}

	/**
	 * Méthode de hook du fichier index.php qui substitue les tags sur toute la page publique.
	 *
	 * @return	null
	 * @author	Humpf
	 **/
	public function IndexEnd() {
		global $output;
		$output = $this->tr->replace($output);
	}
	
	/**
	 * Retourne le tableau des familles de tags chargées
	 *
	 * @return	(array(bool)) tableau associatif des familles de tags chargées.
	 * @author	Humpf
	 **/
	public function getLoadedFamilies() {
		return $this->tr->getLoadedFamilies();
	}
	
} // Classe plxtextreplace

/*
 * Copyright (c) 2012, Humpf
 *
 * This file is part of plxTextReplace.
 * plxTextReplace is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * plxTextReplace is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with plxTextReplace.  If not, see <http://www.gnu.org/licenses/>.
 */
?>