<?php

define('PLX_CHARSET', 'utf-8');
require '../textreplace.php';

# Fonction de vérification du résultat de l'application des patterns
function verifStr($src, $dest) {
	global $tr;
	$result = $tr->replace($src);
	if ($result !== $dest) {
		echo "verif: KO! $src: obtenu=\n";
		var_dump($result);
		echo "attendu=\n";
		var_dump($dest);
		var_dump($tr);
		die();
	}
	echo "verif: OK: $src\n";
}

# Fonction de vérification des différences entres deux tableaux
function verifArray($src, $dest, $msg='') {
	if (count(array_diff_assoc($src, $dest))) {
		echo "verif: KO! $msg: obtenu=\n";
		var_dump($src);
		echo "attendu=\n";
		var_dump($dest);
		die();
	}
	echo "verif: OK: $msg\n";
}


# Initialisation de TextReplace
$tr = new TextReplace();
$tr->loadPatterns('../tags-default.xml');

# Plan de tests BBCode
verifStr('[b]mesg[/b]', '<strong>mesg</strong>');
verifStr('mot [b]mesg[/b]', 'mot <strong>mesg</strong>');
verifStr('[b]mesg[/b]mot', '<strong>mesg</strong>mot');
verifStr('[b]mesg[b]int[/b]mesg[/b]', '<strong>mesg<strong>int</strong>mesg</strong>');
verifStr('[b]mesg[i]int[/i]mesg[/b]', '<strong>mesg<i>int</i>mesg</strong>');
verifStr('[u]super[/u]', "<span style='text-decoration:underline'>super</span>");
verifStr('[s]super[/s]', "<span style='text-decoration:line-through'>super</span>");
verifStr('[color= red ]super[/color]', "<span style='color: red '>super</span>");
verifStr('[font=Arial,"times new roman"]super[/font]', "<span style='font-family:Arial,\"times new roman\"'>super</span>");
verifStr('[img]http://plouc.org/bidule.jpg[/img]', "<img src='http://plouc.org/bidule.jpg'/>");
verifStr('[url]pluxml.org[/url]', "<a href='pluxml.org'>pluxml.org</a>");
verifStr('[url=pluxml.org]CMS PluXml[/url]', "<a href='pluxml.org'>CMS PluXml</a>");

# Plan de tests audioplayer
verifStr('<audioplayer id="12" soundFile="fic.mp3" titles="titre" artists="artiste"/>', <<<EOT
<p id="audioplayer_12">Lecteur Audio</p>
<script type="text/javascript">
AudioPlayer.embed("audioplayer_12", {soundFile: "fic.mp3", titles: "titre", artists: "artiste"});
</script>
EOT
);
verifStr("<audioplayer soundFile  ='fic.mp3'titles=  'titre'artists	=  'artiste' id='12'>", <<<EOT
<p id="audioplayer_12">Lecteur Audio</p>
<script type="text/javascript">
AudioPlayer.embed("audioplayer_12", {soundFile: "fic.mp3", titles: "titre", artists: "artiste"});
</script>
EOT
);
verifStr('<audioplayer id="12" soundFile="fi\'c.mp3" titles="titre" >', <<<EOT
<p id="audioplayer_12">Lecteur Audio</p>
<script type="text/javascript">
AudioPlayer.embed("audioplayer_12", {soundFile: "fi'c.mp3", titles: "titre", artists: ""});
</script>
EOT
);

# Plan de test html5-upgrade
verifStr('<u>super</u>', "<span style='text-decoration:underline'>super</span>");
verifStr('<U class="under">super</u>', "<span style='text-decoration:underline' class=\"under\">super</span>");
verifStr('<s>super</s>', "<span style='text-decoration:line-through'>super</span>");
verifStr('<STRIKE>super</STRIKE>', "<span style='text-decoration:line-through'>super</span>");
verifStr('<font color="red" face=\'Arial,"times new roman"\'>super</font>', "<span style='font: red Arial,\"times new roman\"'>super</span>");
verifStr('<font color = "red">super</font>', "<span style='font: red '>super</span>");
verifStr('<font size="+1">super</font>', "<span style='font:  '>super</span>");
verifStr('<BIG>super</BIG>', "<span style='font-size:110%'>super</span>");
verifStr('<center>super</CENTER>', "<p style='text-align:center'>super</p>");
verifStr('<acronym>super</acronym>', "<abbr>super</abbr>");
verifStr('<TT>super</TT>', "<kbd>super</kbd>");
verifStr('<XMP>super</XMP>', "<pre>super</pre>");
verifStr('<DIR><li>super</DIR>', "<ul><li>super</ul>");
verifStr('<FN ID=AA>mot', "<a id='AA'>mot");
verifStr('<B>Generic MAJ to min</B>', "<b>Generic MAJ to min</b>");

# Plan de tests chargement conditionnel des familles
verifArray($tr->getLoadedFamilies(), array("bbcode"=>true, "audioplayer"=>true, "html5-upgrade"=>true), "Families 3/3");

$tr = new TextReplace(array("html5-upgrade"));
$tr->loadPatterns('../tags-default.xml');
verifArray($tr->getLoadedFamilies(), array("bbcode"=>false, "audioplayer"=>false, "html5-upgrade"=>true), "Families 1/3");

$tr = new TextReplace(array());
$tr->loadPatterns('../tags-default.xml');
verifArray($tr->getLoadedFamilies(), array("bbcode"=>false, "audioplayer"=>false, "html5-upgrade"=>false), "Families 0/3");

# Plan de tests surcharge des tags avec le fichier custom
$tr = new TextReplace(array("bbcode"));
$tr->loadPatterns('../tags-default.xml');
$tr->loadPatterns('tags-test.xml');
verifArray($tr->getLoadedFamilies(), array("bbcode"=>true, "audioplayer"=>false, "html5-upgrade"=>false, "perso" => false), "Surcharge 1");
verifStr('[b]mesg[/b]', '<strong>mesg</strong>');
verifStr('[bip]', '{{bip}}');
verifStr('[pan]', '{{pan_bbcode}}');

$tr = new TextReplace();
$tr->loadPatterns('../tags-default.xml');
$tr->loadPatterns('tags-test.xml');
verifArray($tr->getLoadedFamilies(), array("bbcode"=>true, "audioplayer"=>true, "html5-upgrade"=>true, "perso" => true), "Surcharge 2");
verifStr('[b]mesg[/b]', '<strong>mesg</strong>');
verifStr('[bip]', '{{bip}}');
verifStr('[pan]', '{{pan_perso}}');

# Plan de tests du mode attributes='bbcode'
verifStr('[param|type=sound|src=fic.mp3]', "#param src='fic.mp3' type='sound'");
verifStr('[param| type	=sound| src =fic.mp3]', "#param src='fic.mp3' type='sound'");

/*
 * Copyright (c) 2012, Humpf
 *
 * This file is part of plxTextReplace.
 * plxTextReplace is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * plxTextReplace is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with plxTextReplace.  If not, see <http://www.gnu.org/licenses/>.
 */

?>